@@ -3,11 +3,11 @@ all.Warss<-function(){
      note_for_War_input()
      cat("\n")
      note_for_close_window()
-     WarSSpar<-data.frame(parameter=c("D (mg)","tau (day)","INR"),value=c(0))
+     WarSSpar<-data.frame(parameter=c("D (mg)","tau (day)","INR"),value=c(0,0,0))
      WarSSpar<-edit(WarSSpar)
-     WarSSpar<-wcheck(WarSSpar)
+##     WarSSpar<-wcheck(WarSSpar)
      cat("\n")
-     War.ss(WarSSpar[1,2],WarSSpar[2,2],WarSSpar[3,2])
+     War.ss(WarSSpar[1,2], WarSSpar[2,2], WarSSpar[3,2])
      note_for_convergence_plots()
      convergence_plots_war_sep()
      note_for_War_output()
