@@ -2,9 +2,9 @@
 
    # echo output to screen
    cat("\n")
-   cat("*******************************************************************\n")
-   cat("                Therapeutic Drug Monitoring                        \n")
-   cat("                          v 2.1.1                                  \n\n")   
+   cat("*************************** tdm ***********************************\n")
+   cat("                Therapeutic Drug Monitoring                        \n\n")
+   cat("                          v 2.2.1                                  \n\n")   
    cat("  TDM is created for your own personal uses and testing purposes.  \n")
    cat("  TDM shall be used as a guide or a decision support tool only.    \n")  
    cat("  Medical decisions should NOT be solely based on the results of   \n")
